# TaxStatus


## Enum

* `COMPLETE` (value: `'Complete'`)

* `ERROR` (value: `'Error'`)

* `UNKNOWNERROR` (value: `'UnknownError'`)

* `DUPLICATEDOC` (value: `'DuplicateDoc'`)

* `INVALIDREQUEST` (value: `'InvalidRequest'`)

* `INVALIDRESPONSE` (value: `'InvalidResponse'`)

* `TAXENGINEERROR` (value: `'TaxEngineError'`)

* `CONCURRENTMODIFY` (value: `'ConcurrentModify'`)

* `INTERNALSERVERERROR` (value: `'InternalServerError'`)

* `TAXCODETEMPLATEERROR` (value: `'TaxCodeTemplateError'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


